@REM Copyright IBM Corp. 2003, 2005
@REM
@REM THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
@REM All Rights Reserved * Licensed Materials - Property of IBM
@REM US Government Users Restricted Rights - Use, duplication or disclosure
@REM restricted by GSA ADP Schedule Contract with IBM Corp.

@REM Configuration Based Update Installer

@REM Command Descriptions
@REM 
@REM The '-fix' option specifies an eFix update.
@REM The '-fixpack' option specifies a FixPack update.
@REM The '-install' option specifies an install action.
@REM The '-uninstall' option specifies an uninstall action.
@REM The '-installDir' option specifies the product install root location.
@REM The '-fixDir' option specifies the eFix directory.
@REM The '-fixpackDir' option specifies the FixPack directory.
@REM The '-fixes' specifies a list of eFixes to install or uninstall.
@REM The '-fixpackID' specifies a FixPack to install or uninstall.
@REM The '-fixDetails' option displays eFix detail information.
@REM The '-fixpackDetails' option displays FixPack detail information.
@REM The '-prereqOverride' option overrides any installation prerequisites.
@REM The '<propertyFile>.properties' option specifies an externally supplied parameters file.

@REM Launch Arguments:
@REM
@REM For EFix Processing:
@REM      updatePortal <propertiesFile>
@REM               ( -installDir <product install root>
@REM		  [ -fix ]
@REM                 [ -fixDir <ifix repository root> ]
@REM                 [ -install | -uninstall | -uninstallAll ]
@REM                 [ -fixes <space delimited list of ifixes> ]
@REM                 [ -fixJars <space delimited list of ifix jars> ]
@REM                 [ -fixDetails ]
@REM		         [ -wpcpOnly ( -wpcpInstallDir <Content Publisher install root> ) | -skipWPCP ]
@REM                 [ -configProperties propertiesFile ]
@REM                 [ -prereqOverride ] ) |
@REM               ( -help | -? | /help | /? | -usage )
@REM
@REM For FixPack Processing:
@REM  updatePortal <propertiesFile>
@REM	        ( -installDir <product install root>
@REM		  [ -fixpack ]
@REM                 [ ( -install | -uninstall
@REM 		      -fixpackDir <fixpack repository root> ]
@REM 	              -fixpackID <FixPack ID> ]
@REM		      [ -wpcpOnly ( -wpcpInstallDir <Content Publisher install root> ) | -skipWPCP ]
@REM		      [ -includeOptional <space delimited list of components> ]
@REM              [ -configProperties propertiesFile ]
@REM              [ -fixpackDetails ] ) |
@REM            ( -help | -? | /help | /? | -usage )


@if defined echo (echo %echo% ) else echo off
@setlocal

@REM set DEBUG_UPDATE=yes to turn on debugging statements
set DEBUG_UPDATE=no

@REM CONSOLE_ENCODING controls the output encoding used for stdout/stderr
@REM    console - encoding is correct for a console window
@REM    file    - encoding is the default file encoding for the system
@REM    <other> - the specified encoding is used.  e.g. Cp1252, Cp850, SJIS
SET CONSOLE_ENCODING=-Dws.output.encoding=console

@REM Set classpath for eFix commandline installer
SET CLASSPATH="%~dp0PortalUpdateInstaller.jar"

set LaunchTitle=%0
Echo Start of [ %LaunchTitle% ]
Echo Build 20050921_1320
Echo.

:Silent
Echo Verifying installer jar:
Echo   [ PortalUpdateInstaller.jar ]
Echo.
IF NOT EXIST "%~dp0PortalUpdateInstaller.jar" GoTo FailSilent
GoTo CheckWASHome

:FailSilent
Echo The installer jar file does not exist.  Exiting.
Echo.
GoTo End

:CheckWASHome
IF NOT "%WAS_HOME%" == "" GoTo CheckWasSetup
Echo The WAS_HOME env variable MUST be set.  Exiting.
Echo.
GoTo End

:CheckWasSetup
IF "%DEBUG_UPDATE%" == "yes" Echo Attempting to locate setupCmdLine.bat.
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF EXIST "%WAS_HOME%\bin\setupCmdLine.bat" GoTo RunWasSetup
Echo The WAS_HOME env variable MUST be set.  Exiting.
Echo Unable to locate WAS setupCmdLine.bat in %WAS_HOME%.  Exiting.
Echo.
GoTo End



:RunWasSetup
call "%WAS_HOME%\bin\setupCmdLine.bat"
GoTo TestJDK

:TestJDK
IF NOT EXIST "%JAVA_HOME%\bin" GoTo FailJavaHome
IF NOT EXIST "%JAVA_HOME%\bin\java.exe" GoTo FailJavaHome
goto FixPermissions

:FailJavaHome
Echo The JDK was not found within the set JAVA_HOME:
Echo   JAVA_HOME: [ %JAVA_HOME%\bin\java.exe ]
Echo.
Echo Exiting.
Echo.
goto End

:FixPermissions
:: Set read/write permissions on component files

:: No way to unshift parameters, so must use secondary bat file.
IF EXIST %temp%\wpptfcmp.bat del %temp%\wpptfcmp.bat
echo @echo off > %temp%\wpptfcmp.bat
echo :ShiftIterate >> %temp%\wpptfcmp.bat
echo if "%%~1"=="-installDir" goto GetName >> %temp%\wpptfcmp.bat
echo if "%%~1"=="-installdir" goto GetName >> %temp%\wpptfcmp.bat
echo if "%%~1"=="" goto NoArg >> %temp%\wpptfcmp.bat
echo shift >> %temp%\wpptfcmp.bat
echo goto ShiftIterate >> %temp%\wpptfcmp.bat
echo :NoArg >> %temp%\wpptfcmp.bat
echo goto End >> %temp%\wpptfcmp.bat
echo :GetName  >> %temp%\wpptfcmp.bat
echo SET TARGETDIR=%%~s2>> %temp%\wpptfcmp.bat
echo Echo Setting permissions on %%TARGETDIR%%\version >> %temp%\wpptfcmp.bat
echo IF EXIST %%TARGETDIR%%\version\nul attrib -R %%TARGETDIR%%\version >> %temp%\wpptfcmp.bat 
echo IF EXIST %%TARGETDIR%%\version\nul attrib -R %%TARGETDIR%%\version\* /S /D >> %temp%\wpptfcmp.bat 
echo :End >> %temp%\wpptfcmp.bat

call %temp%\wpptfcmp.bat %*
REM del %temp%\wpptfcmp.bat
goto LaunchInstaller

:LaunchInstaller

REM set DBG_PROP=-Dcom.ibm.websphere.update.ptf.debug=true

"%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% %DBG_PROP% "-Dcom.ibm.wp.pui.systemroot=%SystemRoot%" "-Duser.install.root=%USER_INSTALL_ROOT%" -Dcom.ibm.wp.pui.bld.level=20050921_1320 -Xmx256m -cp "%~dp0PortalUpdateInstaller.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.launch.Launcher com.ibm.websphere.update.silent.UpdateInstaller %*

:End
Echo.
Echo End of [ %LaunchTitle% ]
Echo.
endlocal

