#!/bin/sh
# Copyright IBM Corp. 2004, 2005

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Configuration Based Update Installer
#----------------------------------------------------------------------------------
# Command Descriptions
# 
# The '-fix' option specifies an eFix update.
# The '-fixpack' option specifies a FixPack update.
# The '-install' option specifies an install action.
# The '-uninstall' option specifies an uninstall action.
# The '-installDir' option specifies the product install root location.
# The '-fixDir' option specifies the eFix directory.
# The '-fixpackDir' option specifies the FixPack directory.
# The '-fixes' specifies a list of eFixes to install or uninstall.
# The '-fixpackID' specifies a FixPack to install or uninstall.
# The '-fixDetails' option displays eFix detail information.
# The '-fixpackDetails' option displays FixPack detail information.
# The '-prereqOverride' option overrides any installation prerequisites.
# The '<propertyFile>.properties' option specifies an externally supplied parameters file.
#----------------------------------------------------------------------------------
# Launch Arguments:
#
# For EFix Processing:
#      updatePortal.sh <propertiesFile>
#               ( -installDir <product install root>
#		  [ -fix ]
#                 [ -fixDir <fix repository root> ]
#                 [ -install | -uninstall | -uninstallAll ]
#                 [ -fixes <space delimited list of ifixes> ]
#                 [ -fixJars <space delimited list of ifix jars> ]
#                 [ -fixDetails ]
#                 [ -wpcpOnly ( -wpcpInstallDir <Content Publisher install root> ) ]
#                 [ -configProperties propertiesFile ]
#                 [ -prereqOverride ] ) |
#               ( -help | -? | /help | /? | -usage )
#
# For FixPack Processing:
#  updatePortal.sh <propertiesFile>
#	        ( -installDir <product install root>
#		  [ -fixpack ]
#                 [ ( -install | -uninstall
# 		      -fixpackDir <fixpack repository root> ]
# 	              -fixpackID <FixPack ID> ]
#                 [ -wpcpOnly ( -wpcpInstallDir <Content Publisher install root> ) ]
#		          [ -includeOptional <space delimited list of components> ]
#                 [ -configProperties propertiesFile ]
#                 [ -fixpackDetails ] ) |
#            ( -help | -? | /help | /? | -usage )
#----------------------------------------------------------------------------------

# set DEBUG_UPDATE=yes to turn on debugging statements
DEBUG_UPDATE=

success_rc=0
fail_rc=$?

LaunchTitle=$0

launchInstaller=
useLocalJDK=
prepareJDK=
useJavaHome=
checkSetup=
callSetup=
checkClientSetup=
callClientSetup=
failSetup=
testJDK=
copyJDK=
failedCopyJDK=
okCopyJDK=
fixversionfiles=1

currentDir=`dirname $0`        
PLATFORM=`uname`

#----------------------------------------------------------------------------------
#  Initialization and setup
#----------------------------------------------------------------------------------
echo Start of [ "$LaunchTitle" ]
echo Build 20050921_1320
echo
      
echo Verifying installer jar:
echo   [ PortalUpdateInstaller.jar ]
echo
if [ -f "$currentDir"/PortalUpdateInstaller.jar ] 
then        

    if [ "$PLATFORM" = "OS400" ]
    then
        if [ "$WAS_PROD_HOME" ] 
        then 
            JAVA_HOME="/QIBM/ProdData/Java400/jdk14"
            WP_CP_EXTRA="/QIBM/ProdData/java400/jt400ntv.jar:/QIBM/ProdData/http/public/jt400/lib/jt400.jar"
            WP_JAVA_PARAMS="$WP_JAVA_PARAMS -Djava.version=1.4 -DpermissionHelper=com.ibm.websphere.update.delta.OS400PermissionHelper"
            INSTALLDIR=null
            NEXT=FALSE
            #cp "$WAS_PROD_BASE"/java/extlib/log.jar "$currentDir"/log.jar
            
            for VAR in $@
            do
                    if [ TRUE = "$NEXT" ]
                    then
                             INSTALLDIR=$VAR
                             NEXT=FALSE
                             break
                    fi

                    if [ -INSTALLDIR = "`echo $VAR | tr '[a-z]' '[A-Z]'`" ]
                    then
                             NEXT=TRUE
                    fi
            done

            echo $INSTALLDIR
            
            if [ ! -f "$WAS_PROD_HOME"/lib/xerces.jar ] 
            then
               cp $INSTALLDIR/jcr/rm/WEB-INF/lib/xerces.jar $WAS_PROD_HOME/lib/xerces.jar
            fi        

            if [ ! -s "$INSTALLDIR"/version/EXPRESS.product ] 
            then
               rm "$INSTALLDIR"/version/EXPRESS.product
            fi 
            
            callSetup=1
            
        else
            echo The WAS_PROD_HOME env variable MUST be set.  
            echo Exiting.
            echo
            echo Set WAS_PROD_HOME=/QIBM/ProdData/WebAS5/Base for WebSphere version 5.0.x
            echo Set WAS_PROD_HOME=/QIBM/ProdData/WBISF51/AS for WebSphere version 5.1
            echo Set WAS_PROD_HOME=/QIBM/ProdData/WebSphere/AppServer/V6/Base for WebSphere version 6
            echo
            echo example: export WAS_PROD_HOME=/QIBM/ProdData/WBISF51/AS
            exit $fail_rc
        fi
    else
        if [ "$WAS_HOME" ] 
        then 
            if [ -f "$WAS_HOME"/bin/setupCmdLine.sh ]
            then
                echo Attempting to locate setupClient.sh
                echo
                callSetup=1
            else
                failSetup=1
            fi
        else
            echo The WAS_HOME env variable MUST be set.  
            echo Exiting.
            echo
            exit $fail_rc
        fi
        #make certain supporting files are executable . . .
        chmod -R 755 "${currentDir}"/bin
        chmod_rc=$?
        if [ 0 -ne "${chmod_rc}" ]
        then
            echo Could not set execute permissions on supporting files.
            exit 1
        fi 
         #make certain ws_ant is executable . . .
        chmod -R 755 "${WAS_HOME}"/bin/ws_ant
        chmod_rc=$?
        if [ 0 -ne "${chmod_rc}" ]
        then
            echo Could not set execute permissions on ws_ant.
            exit 1
        fi 

    fi

else
    echo The installer jar file does not exist.  
    echo Exiting.
    echo
    exit $fail_rc
fi     

# Make read-only component file writable.
if [ "$fixversionfiles" ]
    then
    NEXT=FALSE
    for VAR in $@
    do
        if [ TRUE = "$NEXT" ]
        then
            TARGETDIR=$VAR
            NEXT=FALSE
            break
        fi

        if [ -INSTALLDIR = "`echo $VAR | tr '[a-z]' '[A-Z]'`" ]
        then
            NEXT=TRUE
        fi
    done

    echo $TARGETDIR

    if [ "$PLATFORM" != "OS400" ]
    then
        if [ -d "$TARGETDIR"/version ]
        then
            #make certain the version directory and all the files in it are writable
            chmod -fR a+w "$TARGETDIR"/version
            chmod_rc=$?
            if [ 0 -ne "${chmod_rc}" ]
            then
                echo Could not change access mode of version files
            fi 
        else
            echo version directory not found.
        fi
    fi
fi

if [ "$failSetup" ]
   then        
	echo Unable to locate setupCmdLine.sh, this is usually located beneath your
	echo WebSphere AppServer installation, in the 'bin' directory
	echo
	echo Exiting.	
	echo
	exit $fail_rc 
fi

if [ "$callSetup" ]
   then 
                         
        if [ "$PLATFORM" = "OS400" ]
           then
               launchInstaller=1
           else
               CURR_TEMP_DIR=`pwd`
               cd $WAS_HOME/bin
               . $WAS_HOME/bin/setupCmdLine.sh
               cd $CURR_TEMP_DIR
               testJDK=1
        fi
fi

if [ "$testJDK" ]
   then
        if [ -f "$JAVA_HOME"/bin/java ]
           then
                launchInstaller=1
           else
                echo The JDK was not found within the set JAVA_HOME:
        	echo     JAVA_HOME: [ "$JAVA_HOME"/bin/java ]
        	echo
        	echo Exiting.
        	echo
        	exit $fail_rc
        fi           
fi  
      
#PLATFORM=`uname`
export PLATFORM
                 
	                   
#----------------------------------------------------------------------------------
# Set up library loading for native extfile libs
#----------------------------------------------------------------------------------

# Cases for platform specific goop.
case ${PLATFORM} in
        Linux)
                # Select the right arch library for the utils!
                OS_ARCH=`uname -m`
                case ${OS_ARCH} in
                    i386|i486|i586|i686|i786|i886|athlon)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/bin/ia32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    ppc|ppc64)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/bin/ppc32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    s390|s390x)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/bin/s390:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    *)    
                        echo "Unknown Linux Architechture: ${OS_ARCH}. Native file libraries will not be loaded."
                        ;;
                esac
                ;;
        SunOS|Solaris)
                LD_LIBRARY_PATH=${currentDir}/lib/solaris/bin/sparc:${LD_LIBRARY_PATH}
                export LD_LIBRARY_PATH
                ;;
        HP-UX)
                SHLIB_PATH=${currentDir}/lib/hpux/bin/pa-risc:${SHLIB_PATH}
                export SHLIB_PATH
                
                # Make sure this is executable or it won't load!
                if [ ! -x ${currentDir}/lib/hpux/bin/pa-risc/libNativeFile.sl ] ; then
                    chmod 755 ${currentDir}/lib/hpux/bin/pa-risc/libNativeFile.sl
                fi                 
                ;;
        AIX)    
                # Discern between 32 and 64 bit processor
                AIX_PROCESSOR=`bootinfo -K`
                case ${AIX_PROCESSOR} in
                    32)
                        LIBPATH=${currentDir}/lib/aix/bin/ppc32:${LIBPATH}
                        export LIBPATH
                        ;;
                    64)
                        LIBPATH=${currentDir}/lib/aix/bin/ppc64:${LIBPATH}
                        export LIBPATH
                        ;;
                esac
                export LIBPATH
                ;;
        OS400)
        	;;
        *)
                echo "Unknown platform: ${PLATFORM}.  Native file libraries will not be loaded."
                ;;
esac


#----------------------------------------------------------------------------------
# Installer application execution
#----------------------------------------------------------------------------------

# DBG_PROP="-Dcom.ibm.websphere.update.ptf.log.level=5  -Dcom.ibm.ws.update.debug=true -Dcom.ibm.websphere.update.ptf.debug=true -Dcom.ibm.websphere.update.harness.debug=true"
# export DBG_PROP

if [ "$launchInstaller" ] 
then                  
    "$JAVA_HOME"/bin/java \
    -Xmx256m \
    -cp "$WP_CP_EXTRA":"$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
    -DCURRENT_UPDATE_DIR="${currentDir}" \
    -DWAS_PROD_BASE_PATH="$WAS_PROD_HOME" \
    -Dcom.ibm.wp.pui.bld.level=20050921_1320 \
    -Duser.install.root="$USER_INSTALL_ROOT" \
    $WP_JAVA_PARAMS \
    ${DBG_PROP} \
    com.ibm.websphere.update.launch.Launcher \
    com.ibm.websphere.update.silent.UpdateInstaller $@
fi

#ensure appropriate file system ownership on iSeries
if [ "$PLATFORM" = "OS400" ]
then
   chown -R QEJBSVR "$INSTALLDIR"
fi   

echo End of [ "$LaunchTitle" ]
echo 
exit $success_rc
