@REM Copyright IBM Corp. 2004
@REM
@REM THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
@REM All Rights Reserved * Licensed Materials - Property of IBM
@REM US Government Users Restricted Rights - Use, duplication or disclosure
@REM restricted by GSA ADP Schedule Contract with IBM Corp.

@REM Configuration Based Update Installer

@REM Command Descriptions
@REM
@REM The '-installDir' option specifies the product install root location (ISC_HOME)
@REM The '-fixDir' option specifies ISC fix directory
@REM The '-stopServers' option specifies the WebSphere Application Server should be stopped prior to update
@REM The '-norestart' option specifies the WebSphere Application Server should not be restarted after the update
@REM The '-wasAdmin' option specifies the WAS Administrators ID, used to stop/start servers
@REM The '-wasAdminPw' option specifies the WAS Administrators Password, used to stop/start servers
@REM The '-install' option specifies the install action
@REM The '-uninstall' option specifies the uninstall action
@REM The '-fixList' option specifies the list of ISC fixes to process
@REM The '-version' option returns current version of ISC (No installs occur if this is specified)

@REM Launch Arguments:
@REM
@REM For Fix Processing:
@REM	updateISC ( -installDir "<ISC install root>"
@REM			( -install | -uninstall )
@REM			[ -fixDir "<ISC fix directory>" ]
@REM			-fixList <space delimeted list of ISC fixes>
@REM			[ -stopServers ]
@REM			[ -norestart ]
@REM			[ -wasAdmin <ID> ]
@REM			[ -wasAdminPw <PW> ] ) |
@REM		  ( -version ) |
@REM		  ( -help | -? | /help | /? | -usage )

@if defined echo (echo %echo% ) else echo off
@setlocal

@REM set DEBUG_UPDATE=yes to turn on debugging statements
set DEBUG_UPDATE=no

@REM CONSOLE_ENCODING controls the output encoding used for stdout/stderr
@REM    console - encoding is correct for a console window
@REM    file    - encoding is the default file encoding for the system
@REM    <other> - the specified encoding is used.  e.g. Cp1252, Cp850, SJIS
SET CONSOLE_ENCODING=-Dws.output.encoding=console

@REM Set classpath for eFix commandline installer
SET CLASSPATH="%~dp0ISCUpdateInstaller.jar"

set LaunchTitle=%0
Echo Start of [ %LaunchTitle% ]
Echo.

:Silent
Echo Verifying installer jar:
Echo   [ ISCUpdateInstaller.jar ]
Echo.
IF NOT EXIST "%~dp0ISCUpdateInstaller.jar" GoTo FailSilent
GoTo CheckISCHome

:FailSilent
Echo The installer jar file does not exist.  Exiting.
Echo.
GoTo End

:CheckISCHome
set ISC_HOME=
set IUI_DIR=%~dp0
GoTo Loop

:ShiftLoop
SHIFT

:Loop
IF /i "%1" == "-installDir" set ISC_HOME=%~2
IF /i "%1" == "-installDir" GoTo CheckISCSetup

IF "%1" == "" GoTo TestJDK
GoTo ShiftLoop

REM :FailISCHome
REM Echo The '-installDir' parameter MUST be specified. Exiting.
REM Echo    For more information: [ updateISC.bat -help ]
REM GoTo End

:CheckISCSetup
IF "%DEBUG_UPDATE%" == "yes" Echo Attempting to locate isc.properties.
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF EXIST "%ISC_HOME%\isc.properties" GoTo TestJDK
Echo Unable to locate isc.properties in %ISC_HOME%.
Echo Please ensure you have specified the proper value for -installDir.
Echo.
Echo Exiting.
GoTo End

:TestJDK
IF NOT EXIST "%JAVA_HOME%\bin" GoTo FailJavaHome
IF NOT EXIST "%JAVA_HOME%\bin\java.exe" GoTo FailJavaHome
GoTo LaunchInstaller

:FailJavaHome
Echo The JDK was not found within the set JAVA_HOME:
Echo   JAVA_HOME: [ %JAVA_HOME%\bin\java.exe ]
Echo.
Echo Exiting.
Echo.
GoTo End

:LaunchInstaller
REM set DBG_PROP=-Dcom.ibm.websphere.update.ptf.debug=true

"%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% %DBG_PROP% -Xmx256m -cp "%IUI_DIR%ISCUpdateInstaller.jar" com.ibm.isc.update.silent.UpdateInstaller %*

:End
Echo.
Echo End of [ %LaunchTitle% ]
Echo.
endlocal
