#!/bin/sh
# Copyright IBM Corp. 2004 2005

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Configuration Based Update Installer
#----------------------------------------------------------------------------------
# Command Descriptions
#
# The '-installDir' option specifies the product install root location (ISC_HOME)
# The '-fixDir' option specifies ISC fix directory
# The '-stopServers' option specifies the WebSphere Application Server should be stopped prior to update
# The '-norestart' option specifies the WebSphere Application Server should not be restarted after the update
# The '-wasAdmin' option specifies the WAS Administrators ID, used to stop/start servers
# The '-wasAdminPw' option specifies the WAS Administrators Password, used to stop/start servers
# The '-install' option specifies the install action
# The '-uninstall' option specifies the uninstall action
# The '-fixList' option specifies the list of ISC fixes to process
# The '-version' option returns current version of ISC (No installs occur if this is specified)
#
#----------------------------------------------------------------------------------
# Launch Arguments:
#
# For Fix Processing:
#	updateISC.sh ( -installDir "<ISC install root>"
#			( -install | -uninstall )
#			[ -fixDir "<ISC fix directory>" ]
#			-fixList <space delimeted list of ISC fixes>
#			[ -stopServers ]
#			[ -norestart ]
#			[ -wasAdmin <ID> ]
#			[ -wasAdminPw <PW> ] ) |
#		     ( -version ] ) |
#		     ( -help | -? | /help | /? | -usage )
#
#----------------------------------------------------------------------------------

# set DEBUG_UPDATE=yes to turn on debugging statements
DEBUG_UPDATE=

ISC_HOME=null

success_rc=0
fail_rc=1

LaunchTitle=$0

launchInstaller=
callSetup=1
failSetup=
testJDK=

currentDir=`dirname $0`
PLATFORM=`uname`

#----------------------------------------------------------------------------------
#  Initialization and setup
#----------------------------------------------------------------------------------
echo Start of [ "$LaunchTitle" ]
echo

echo Verifying installer jar:
echo   [ ISCUpdateInstaller.jar ]
echo
if [ -f "$currentDir"/ISCUpdateInstaller.jar ]
   then

        if [ "$PLATFORM" = "OS400" ]
           then
        	JAVA_HOME="/QIBM/ProdData/Java400/jdk14"
                WP_CP_EXTRA="/QIBM/ProdData/java400/jt400ntv.jar:/QIBM/ProdData/http/public/jt400/lib/jt400.jar"
                WP_JAVA_PARAMS="$WP_JAVA_PARAMS -Djava.version=1.4"
                ISC_HOME=null
                NEXT=FALSE

                for VAR in $@
                do
		        if [ TRUE = "$NEXT" ]
			   then
			   	ISC_HOME=$VAR
				NEXT=FALSE
				 if [ -f "$ISC_HOME"/isc.properties ]
				    then
					#echo Attempting to locate isc.properties
					callSetup=1
				    else
					failSetup=1
					callSetup=0
		 		 fi
			fi
		        if [ -INSTALLDIR = "`echo $VAR | tr '[a-z]' '[A-Z]'`" ]
		           then
		 		 NEXT=TRUE
		        fi
                done

        else
		ISC_HOME=null
		NEXT=FALSE
            	
		for VAR in $@
	        do
			if [ TRUE = "$NEXT" ]
			   then
				ISC_HOME=$VAR
				NEXT=FALSE
	                        if [ -f "$ISC_HOME"/isc.properties ]
	                           then
	                        	#echo Attempting to locate isc.properties
	                                callSetup=1
	                        else
	                        	failSetup=1
	                        	callSetup=0
	                        fi
			fi
			if [ -INSTALLDIR = "`echo $VAR | tr "[:lower:]" "[:upper:]"`" ]
			   then
				NEXT=TRUE
			fi
		done
        fi

   else
        echo The installer jar file does not exist.
        echo Exiting.
        echo
        exit $fail_rc
fi

if [ "$failSetup" ]
   then
	echo
	echo Unable to locate isc.properties in $ISC_HOME.
	echo Please ensure you have specified the proper value for -installDir.
	echo
	echo Exiting.
	exit $fail_rc
fi

if [ "$callSetup" ]
   then

        if [ "$PLATFORM" = "OS400" ]
           then
               launchInstaller=1
           else
               testJDK=1
        fi
fi

if [ "$testJDK" ]
   then
        if [ -f "$JAVA_HOME"/bin/java ]
           then
                launchInstaller=1
           else
                echo The JDK was not found within the set JAVA_HOME:
        	echo     JAVA_HOME: [ "$JAVA_HOME"/bin/java ]
        	echo
        	echo Exiting.
        	echo
        	exit $fail_rc
        fi
fi

#PLATFORM=`uname`
export PLATFORM

	
#----------------------------------------------------------------------------------
# Set up library loading for native extfile libs
#----------------------------------------------------------------------------------

# Cases for platform specific goop.
case ${PLATFORM} in
        Linux)
                # Select the right arch library for the utils!
                OS_ARCH=`uname -m`
                case ${OS_ARCH} in
                    i386|i486|i586|i686|i786|i886|athlon)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/i386:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    ppc|ppc64)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/ppc32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    s390)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/s390:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                esac
                ;;
        SunOS|Solaris)
                LD_LIBRARY_PATH=${currentDir}/lib/solaris:${LD_LIBRARY_PATH}
                export LD_LIBRARY_PATH
                ;;
        HP-UX)
                SHLIB_PATH=${currentDir}/lib/hpux:${SHLIB_PATH}
                export SHLIB_PATH

                # Make sure this is executable or it won't load!
                if [ ! -x ${currentDir}/lib/hpux/libUnixFileUtils.sl ] ; then
                    chmod 755 ${currentDir}/lib/hpux/libUnixFileUtils.sl
                fi
                ;;
        AIX)
                LIBPATH=${currentDir}/lib/aix:${LIBPATH}
                export LIBPATH
                ;;
        OS400)
        	;;
        *)
                echo "Unknown platform: ${PLATFORM}.  Native file libraries will not be loaded."
                ;;
esac


#----------------------------------------------------------------------------------
# Installer application execution
#----------------------------------------------------------------------------------

if [ "$launchInstaller" ]
then
           "$JAVA_HOME"/bin/java \
            -Xmx256m \
            -cp "$WP_CP_EXTRA":"$currentDir"/ISCUpdateInstaller.jar \
            $WP_JAVA_PARAMS \
            com.ibm.isc.update.silent.UpdateInstaller $@
            fail_rc=$?
fi

echo End of [ "$LaunchTitle" ]
echo
exit $fail_rc
